package PureMessage::Sophos::SAVI::AttachmentScan::Config;

use strict;
use warnings;

use base qw(PureMessage::Config::Validator Exporter);
use PureMessage::Config qw(expand_filename);

our @EXPORT_OK = qw(%attach_config);
our %attach_config;

refresh();

sub refresh {
    require PureMessage::Config::Validator;

    my $p = ActiveState::Config->new(strict => 1, allow_includes => 1);

    PureMessage::Config::Validator->define_core_validators($p);
    PureMessage::Sophos::SAVI::AttachmentScan::Config->validate($p);
    $p->parse_file(expand_filename('etc/data/tft/attach_scan.conf'));

    %attach_config = $p->as_hash;
}


sub validate {
    my ($pkg, $p) = @_;

    my %conf = (
    'inspect_archives.enabled'                  => ['#bool', 1],
    'inspect_archives.max_recursion_depth'      => ['#int', undef],
    );

    foreach my $k (keys %conf) {
    my ($t, $d) = @{$conf{$k}};

    $p->typedecl($k, $t) if defined $t;
    $p->default($k, $d) if defined $d;
    }

    require Sophos::SAVI::Config;
    Sophos::SAVI::Config->validate($p);
}

1;
