package PureMessage::Sophos::SAVI::TFT::Config;

use strict;
use warnings;

use base qw(PureMessage::Config::Validator Exporter);
use PureMessage::Config qw(expand_filename);

our @EXPORT_OK = qw(%tft_config);
our %tft_config;

refresh();

sub refresh {
    require PureMessage::Config::Validator;

    my $p = ActiveState::Config->new(strict => 1, allow_includes => 1);

    PureMessage::Config::Validator->define_core_validators($p);
    PureMessage::Sophos::SAVI::TFT::Config->validate($p);
    $p->parse_file(expand_filename('etc/tft.conf'));
    $p->parse_file(expand_filename('etc/data/tft/sophos.conf'));

    my $tft_mapping_file = expand_filename('etc/data/sophos/filetypes.conf');
    if (!-e $tft_mapping_file) {
         $tft_mapping_file = expand_filename('etc/data/tft/filetypes.conf');
    }
    $p->parse_file($tft_mapping_file);

    %tft_config = $p->as_hash;

    # Re-map the TFT ids for easy lookup by ID name
    foreach my $k (keys(%{$tft_config{id}})) {
        my $name = delete $tft_config{id}{$k}{name};
        $tft_config{ids}{$name} = delete $tft_config{id}{$k};
    }
    delete $tft_config{id};
}

sub validate {
    my ($pkg, $p) = @_;

    my %conf = (
	'inspect_archives.enabled'		=> ['#bool', 1],
	'inspect_archives.max_recursion_depth'	=> ['#int', undef],
	'mapping#*._*'				=> ['#str'],
        'extensions.*'                          => ['#str'],
        'mime_types.*'                          => ['#str'],
        # filetypes.conf:
        'id#*.name'                             => ['#str'],
        'id#*.extensions'                       => ['#list #str'],
        'id#*.mime_types'                       => ['#list #str'],
    );

    foreach my $k (keys %conf) {
	my ($t, $d) = @{$conf{$k}};

	$p->typedecl($k, $t) if defined $t;
	$p->default($k, $d) if defined $d;
    }

    require Sophos::SAVI::Config;
    Sophos::SAVI::Config->validate($p);
}

1;
